# Generated by roxygen2: do not edit by hand

S3method(read_pin_conn,conn_matrix_table)
S3method(read_pin_conn,conn_spatial_table)
S3method(write_pin_conn,dbMatrix)
S3method(write_pin_conn,dbSpatial)
S3method(write_pin_conn,default)
S3method(write_pin_conn,tbl)
S3method(write_pin_conn,tbl_duckdb_connection)
S3method(write_pin_conn,tbl_lazy)
S3method(write_pin_conn,tbl_sql)
export("conn<-")
export(.check_con)
export(.check_name)
export(.check_overwrite)
export(.check_tbl)
export(conn)
export(connection_pin_read)
export(dbList)
export(dbLoad)
export(dbProject)
export(dbReconnect)
export(is_view)
export(read_pin_conn)
export(to_view)
export(unique_table_name)
export(write_pin_conn)
exportClasses(dbData)
exportMethods("[")
exportMethods("[<-")
exportMethods("conn<-")
exportMethods(conn)
exportMethods(dbList)
exportMethods(dbReconnect)
exportMethods(to_view)
import(methods)
importFrom(R6,R6Class)
importFrom(connections,connection_close)
importFrom(connections,connection_open)
importFrom(connections,connection_pin_read)
importFrom(connections,connection_pin_write)
importFrom(methods,is)
importFrom(methods,setClass)
importFrom(methods,setClassUnion)
importFrom(methods,setGeneric)
importFrom(methods,setMethod)
importFrom(methods,setReplaceMethod)
importFrom(utils,packageVersion)
importFrom(yaml,read_yaml)
