## ----include = FALSE----------------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)

## ----diagnostic-example-------------------------------------------------------
library(dbProject)

project_path <- tempfile("dbproject-troubleshooting-")
proj <- dbProject$new(path = project_path)
proj$is_connected()
proj$disconnect()
proj$is_connected()
unlink(project_path, recursive = TRUE)

