#' @importFrom methods setClass setClassUnion setGeneric setMethod setReplaceMethod is
#' @importFrom utils packageVersion
#' @importFrom R6 R6Class
#' @importFrom connections connection_open connection_close connection_pin_read connection_pin_write
#' @importFrom yaml read_yaml
NULL