% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/input-validation.R
\name{is_view}
\alias{is_view}
\title{Check if a database object is a VIEW}
\usage{
is_view(conn, name)
}
\arguments{
\item{conn}{DBI connection (must be duckdb)}

\item{name}{Character, object name to check}
}
\value{
Logical, TRUE if the object is a VIEW
}
\description{
Check if a database object is a VIEW
}
\keyword{internal}
