% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dbMatrix-pin.R
\name{write_pin_conn.dbMatrix}
\alias{write_pin_conn.dbMatrix}
\title{Write a dbMatrix object to a pins board}
\usage{
\method{write_pin_conn}{dbMatrix}(x, board, name, ...)
}
\arguments{
\item{x}{A dbMatrix object (dbSparseMatrix or dbDenseMatrix)}

\item{board}{A pins \code{\link[pins:board_folder]{pins::board_folder}} object}

\item{name}{Name for the pin (required)}

\item{...}{Additional arguments passed to \code{\link[pins:pin_read]{pins::pin_write()}}}
}
\value{
Invisibly returns the input object
}
\description{
S3 method for writing dbMatrix objects to a pins board while maintaining
connection state and metadata consistent with the connections package.
}
