% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/generics.R
\name{dbverse-generics}
\alias{dbverse-generics}
\title{Generic Function Definitions for dbverse}
\description{
This file contains all generic function definitions for the dbverse ecosystem.
All generics are defined here once to avoid duplicate definition errors.
Method implementations are defined in their respective files.
}
\details{
Centralizing generic definitions helps avoid the "no method found for function..."
error that occurs when the same generic is defined in multiple files.
}
\keyword{internal}
