% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/input-validation.R
\name{.check_name}
\alias{.check_name}
\title{Validate table name}
\usage{
.check_name(name)
}
\arguments{
\item{name}{Character, table name}
}
\description{
Validate table name
}
\keyword{internal}
