% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/input-validation.R
\name{.check_overwrite}
\alias{.check_overwrite}
\title{Validate overwrite parameter and handle existing objects}
\usage{
.check_overwrite(conn, overwrite, name, skip_value_check = FALSE)
}
\arguments{
\item{conn}{DBI connection}

\item{overwrite}{Logical or "PASS" token}

\item{name}{Table name}

\item{skip_value_check}{Logical, if TRUE skip value-based checks (used by dbMatrix)}
}
\description{
Validate overwrite parameter and handle existing objects
}
\keyword{internal}
