% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/connection-registry.R
\docType{data}
\name{.db_registry}
\alias{.db_registry}
\title{Registry to track live connections}
\format{
An object of class \code{environment} of length 0.
}
\usage{
.db_registry
}
\description{
The registry provides O(1) lookups from database file paths
to cached live connections. This enables fast reconnection
and connection de-duplication when a connection becomes invalid.

Entries are keyed by normalized database file path.
Live connections are stored under \code{paste0("conn:", dir)}.
}
\keyword{internal}
