% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/generics.R
\name{dbList}
\alias{dbList}
\title{List remote tables, temporary tables, and views}
\usage{
dbList(conn, ...)
}
\arguments{
\item{conn}{A DBI database connection}

\item{...}{Additional arguments passed to methods}
}
\value{
Method implementations may return different formats, typically a categorized list
}
\description{
A generic function to list tables, temporary tables, and views in a database connection.
This provides an enhanced view over DBI::dbListTables with categorization.
}
\seealso{
\code{\link[DBI:dbListTables]{DBI::dbListTables()}}
}
