% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dbMatrix-pin.R
\name{write_pin_conn.default}
\alias{write_pin_conn.default}
\title{Default method for write_pin_conn}
\usage{
\method{write_pin_conn}{default}(x, board, ...)
}
\arguments{
\item{x}{Any R object}

\item{board}{A pins board object}

\item{...}{Additional arguments passed to pins::pin_write()}
}
\value{
Invisibly returns the input object
}
\description{
Fallback method for non-database objects. Delegates directly to
pins::pin_write() for regular R objects (matrices, data.frames, vectors, etc.)
}
